@@ -727,7 +727,7 @@ notes."
   (find-file
    (file-truename
     (concat compost-thermo-directory "/"
-            (pad-whitaker-string
+            (compost--pad-whitaker-string-to-5-ranks
              (compost--convert-number-to-whitaker-string
               current-number))
             ".txt")))))
@@ -925,6 +925,37 @@ None."
       0
     (expt base (- rank 1))))
 
+(defun compost--highest-rank-needed (number base &optional guess)
+  "Compute the highest rank needed to represent NUMBER in a given numeric
+BASE.
+
+This is a CALCULATION.
+
+Arguments
+=========
+
+NUMBER<number>: The number in question.
+
+BASE<number>: The numeric base to be used.
+
+GUESS<number>: A possible solution, to be tested heuristically.
+
+Returns
+=======
+
+A <number> representing the highest rank needed to represent NUMBER in
+the given BASE.
+
+Impurities
+==========
+
+None.
+"
+  (let ((guess (if guess guess 0)))
+    (if (> (expt base guess) number)
+        guess
+      (compost--highest-rank-needed number base (+ guess 1)))))
+
 (defun compost-meso-new-thought ()
   "Close the current thought in a meso file, and start a new one.
 
